summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorraysan5 <[email protected]>2018-01-06 02:51:28 +0100
committerraysan5 <[email protected]>2018-01-06 02:51:28 +0100
commit1f0f8c33fa8c1033dcf3037524504f2317f5777a (patch)
tree4e33b3765c62f308376ea23f532607f6bfd03bed /src/raylib.h
parent7fa28611607c210789054056095588b17c5bdaac (diff)
downloadraylib-1f0f8c33fa8c1033dcf3037524504f2317f5777a.tar.gz
raylib-1f0f8c33fa8c1033dcf3037524504f2317f5777a.zip
Added function declaration
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 01699ae7..a2f28661 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -869,7 +869,7 @@ RLAPI void UnloadImage(Image image);
RLAPI void UnloadTexture(Texture2D texture); // Unload texture from GPU memory (VRAM)
RLAPI void UnloadRenderTexture(RenderTexture2D target); // Unload render texture from GPU memory (VRAM)
RLAPI Color *GetImageData(Image image); // Get pixel data from image as a Color struct array
-RLAPI int GetImageDataSize(Image image); // Get image data size in bytes
+RLAPI int GetPixelDataSize(int width, int height, int format); // Get pixel data size in bytes (image or texture)
RLAPI Image GetTextureData(Texture2D texture); // Get pixel data from GPU texture and return an Image
RLAPI void UpdateTexture(Texture2D texture, const void *pixels); // Update GPU texture with new data
RLAPI void SaveImageAs(const char *fileName, Image image); // Save image to a PNG file